==> plantuml-libs-7.1.0.tgz: package/distribution/azure-4/Item/General/ServiceBrowser.md <==
# ServiceBrowser


```text
azure-4/Item/General/ServiceBrowser
```

```text
include('azure-4/Item/General/ServiceBrowser')
```



| Illustration | ServiceBrowser | ServiceBrowserCard | ServiceBrowserGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceBrowser.png) | ![illustration for ServiceBrowser](../../../azure-4/Item/General/ServiceBrowser.Local.png) | ![illustration for ServiceBrowserCard](../../../azure-4/Item/General/ServiceBrowserCard.Local.png) | ![illustration for ServiceBrowserGroup](../../../azure-4/Item/General/ServiceBrowserGroup.Local.png) |




## ServiceBrowser

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowser
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowser('ServiceBrowser', 'Service Browser', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowser
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowser('ServiceBrowser', 'Service Browser', 'an optional tech label')
@enduml
```

## ServiceBrowserCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserCard
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserCard('ServiceBrowserCard', 'Service Browser Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserCard
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserCard('ServiceBrowserCard', 'Service Browser Card', 'an optional description')
@enduml
```

## ServiceBrowserGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserGroup
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserGroup('ServiceBrowserGroup', 'Service Browser Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserGroup
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserGroup('ServiceBrowserGroup', 'Service Browser Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/azure-4/Item/General/ServiceBrowser.md <==
# ServiceBrowser


```text
azure-4/Item/General/ServiceBrowser
```

```text
include('azure-4/Item/General/ServiceBrowser')
```



| Illustration | ServiceBrowser | ServiceBrowserCard | ServiceBrowserGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceBrowser.png) | ![illustration for ServiceBrowser](../../../azure-4/Item/General/ServiceBrowser.Local.png) | ![illustration for ServiceBrowserCard](../../../azure-4/Item/General/ServiceBrowserCard.Local.png) | ![illustration for ServiceBrowserGroup](../../../azure-4/Item/General/ServiceBrowserGroup.Local.png) |




## ServiceBrowser

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowser
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowser('ServiceBrowser', 'Service Browser', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowser
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowser('ServiceBrowser', 'Service Browser', 'an optional tech label', 'an optional description')
@enduml
```

## ServiceBrowserCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserCard
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserCard('ServiceBrowserCard', 'Service Browser Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserCard
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserCard('ServiceBrowserCard', 'Service Browser Card', 'an optional description')
@enduml
```

## ServiceBrowserGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserGroup
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserGroup('ServiceBrowserGroup', 'Service Browser Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBrowserGroup
include('azure-4/Item/General/ServiceBrowser')

' renders the element
ServiceBrowserGroup('ServiceBrowserGroup', 'Service Browser Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
